<?php
/**
 * Reduxbiz functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Reduxbiz
 */

/**
 * Define Theme Name
 */
$reduxbiz_themename = get_option( 'stylesheet' );
$reduxbiz_themename = preg_replace("/\W/", "_", strtolower( $reduxbiz_themename ) );
define( 'REDUX_THEME_NAME', $reduxbiz_themename );
	
/**
 * Define Directory Location Constants
 */
define( 'REDUX_PARENT_DIR', get_template_directory() );
define( 'REDUX_CHILD_DIR', get_stylesheet_directory() );

/**
 * Define URL Location Constants
 */
define( 'REDUX_PARENT_URL', get_template_directory_uri() );
define( 'REDUX_CHILD_URL', get_stylesheet_directory_uri() );

if ( ! function_exists( 'reduxbiz_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function reduxbiz_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Reduxbiz, use a find and replace
	 * to change 'reduxbiz' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'reduxbiz', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'reduxbiz-big-thumb', 400, 300, true );
	add_image_size( 'reduxbiz-big-thumb', 2000, 1500, true );

	// Enable support for custom logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 130,
		'height'      => 65,
		'flex-height' => true,
		'header-text' => array( 'site-title', 'site-description' ),
	) );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'reduxbiz' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

}
endif;
add_action( 'after_setup_theme', 'reduxbiz_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function reduxbiz_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'reduxbiz_content_width', 900 );
}
add_action( 'after_setup_theme', 'reduxbiz_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function reduxbiz_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'reduxbiz' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget widget-small %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Top Footer', 'reduxbiz' ),
		'id'            => 'sidebar-2',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Bottom Footer', 'reduxbiz' ),
		'id'            => 'sidebar-3',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget widget-small %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'reduxbiz_widgets_init' );

if ( ! function_exists( 'reduxbiz_fonts_url' ) ) :
/**
 * Register Google fonts for Reduxbiz.
 *
 * Create your own reduxbiz_fonts_url() function to override in a child theme.
 *
 * @return string Google fonts URL for the theme.
 */
function reduxbiz_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/* translators: If there are characters in your language that are not supported by Poppins, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== esc_html_x( 'on', 'Poppins font: on or off', 'reduxbiz' ) ) {
		$fonts[] = 'Poppins:400,700';
	}

	/* translators: If there are characters in your language that are not supported by Lato, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== esc_html_x( 'on', 'Lato font: on or off', 'reduxbiz' ) ) {
		$fonts[] = 'Lato:400,700,400italic,700italic';
	}

	/* translators: If there are characters in your language that are not supported by Inconsolata, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== esc_html_x( 'on', 'Inconsolata font: on or off', 'reduxbiz' ) ) {
		$fonts[] = 'Inconsolata:400,700';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;
}
endif;

/**
 * Enqueue scripts and styles.
 */
function reduxbiz_scripts() {
	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/genericons/genericons.css', array(), '3.4.1' );

	wp_enqueue_style( 'reduxbiz-fonts', reduxbiz_fonts_url(), array(), null );

	wp_enqueue_style( 'reduxbiz-style', get_stylesheet_uri() );

	wp_enqueue_script( 'reduxbiz-back-top', get_template_directory_uri() . '/js/back-top.js', array(), '20120206', true );

	wp_enqueue_script( 'reduxbiz-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	wp_enqueue_script( 'reduxbiz-navigation', get_template_directory_uri() . '/js/navigation.js', array( 'jquery' ), '20151231', true );

	if ( reduxbiz_options('sticky_header' ) ) {
		wp_enqueue_script( 'reduxbiz-header', get_template_directory_uri() . '/js/header.js', array(), '20130115', true );
	}

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_localize_script( 'reduxbiz-back-top', 'reduxbizButtonTitle', array(
		'desc' => esc_html__( '', 'reduxbiz' ),
	) );

	wp_localize_script( 'reduxbiz-navigation', 'reduxbizScreenReaderText', array(
		'expand'   => esc_html__( 'Expand Child Menu', 'reduxbiz' ),
		'collapse' => esc_html__( 'Collapse Child Menu', 'reduxbiz' ),
	) );
}
add_action( 'wp_enqueue_scripts', 'reduxbiz_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer-custom-css.php';

/**
 * Add Theme Go Pro link to customizer.
 */
require_once ( trailingslashit( get_template_directory() ) . '/inc/customizer-pro/class-customize.php' );

/**
 * Retrieve and handle theme options.
 */
function reduxbiz_options( $id, $default = false ) {

   // getting options value
   $reduxbiz_options = get_theme_mod( REDUX_THEME_NAME );
   if ( isset( $reduxbiz_options[ $id ] ) ) {
      return $reduxbiz_options[ $id ];
   } else {
      return $default;
   }
}

/**
 * Reset and delete Redux theme options.
 */
add_action('wp_ajax_reduxbiz_theme_reset', 'reduxbiz_theme_reset_callback');

function reduxbiz_theme_reset_callback(){
	$reset_value = esc_attr($_POST['reduxbiz_theme_reset']);
	
	if($reset_value){
		remove_theme_mods() ;
	}
}

/**
 * Add theme dashboard page.
 */
 require get_template_directory() . '/inc/dashboard-page.php';

/**
 * Define allowed HTML for wp_kses
 */

global $allowed_html;

$allowed_html = array(
    'a' => array(
        'href' => array(),
        'title' => array()
    ),
    'br' => array(),
    'p' => array(),
    'hr' => array(),
    'strong' => array(),
    'h1' => array(),
    'h2' => array(),
    'h3' => array(),
    'h4' => array(),
);