<?php
/**
 * Reduxbiz Theme CSS.
 *
 * @package Reduxbiz
 */

add_action('wp_head', 'reduxbiz_custom_CSS');

/**
 * Styles the custom css
 */
function reduxbiz_custom_CSS() {
	
	$primary_color = reduxbiz_options('primary_color');
	$button_color = reduxbiz_options('button_color');

	/*
	 * If no custom options for text are set, let's bail.
	 * get_header_textcolor() options: add_theme_support( 'custom-header' ) is default, hide text (returns 'blank') or any hex value.
	 */

	if ( ( $primary_color != '') && ($primary_color != '#19bce9')) : ?>
	<style type="text/css">
		.site-title a,
		.site-description {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		blockquote {
			border: 0 solid <?php echo esc_attr( $primary_color ); ?>;
		}
		mark,
		ins {
			background: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		button,
		input[type="button"],
		input[type="reset"],
		input[type="submit"] {
			background: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.widget-footer-top-area button,
		.widget-footer-top-area input[type="button"],
		.widget-footer-top-area input[type="reset"],
		.widget-footer-top-area input[type="submit"] {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="url"]:focus,
		input[type="password"]:focus,
		input[type="search"]:focus,
		input[type="number"]:focus,
		input[type="tel"]:focus,
		input[type="range"]:focus,
		input[type="date"]:focus,
		input[type="month"]:focus,
		input[type="week"]:focus,
		input[type="time"]:focus,
		input[type="datetime"]:focus,
		input[type="datetime-local"]:focus,
		input[type="color"]:focus,
		select:focus,
		textarea:focus {
			outline: 2px solid <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.search-form .search-submit:before {
			background: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.site-title a {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.site-info a:focus,
		.site-info a:hover {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.widget-footer-top-area {
			background: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		a:focus,
		a:hover {
			color: <?php echo esc_attr( $primary_color ); ?>;
			outline: 0;
		}
		
		.comment-metadata a:focus,
		.comment-metadata a:hover,
		.entry-footer a:focus,
		.entry-footer a:hover,
		.entry-header a:focus,
		.entry-header a:hover {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.main-navigation .menu-item-has-children > a:after {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		
		.main-navigation a:focus,
		.main-navigation a:hover {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.main-navigation .primary-menu .current_page_item > a,
		.main-navigation .primary-menu .current-menu-item > a,
		.main-navigation .primary-menu .current_page_ancestor > a {
			border-color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.post-navigation a:focus .post-title,
		.post-navigation a:hover .post-title {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.comment-navigation .nav-previous a:before,
		.posts-navigation .nav-previous a:before,
		.comment-navigation .nav-next a:after,
		.posts-navigation .nav-next a:after {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		
		.featured-content .flex-control-paging a {
			border: 2px solid <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.featured-content .flex-control-paging a:hover,
		.featured-content .flex-control-paging .flex-active {
			background: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.comment-reply-link:after {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.site .wp-playlist-light a.wp-playlist-caption:focus,
		.site .wp-playlist-light a.wp-playlist-caption:hover {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		#infinite-footer {
			background: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		
		.site-main #infinite-handle span button,
		.site-main #infinite-handle span button:focus,
		.site-main #infinite-handle span button:hover {
			background: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.infinite-loader .spinner div {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.site .jetpack-social-navigation a:hover,
		.site .jetpack-social-navigation a:focus {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.widget_akismet_widget .a-stats a:focus,
		.widget_akismet_widget .a-stats a:hover {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.widget_goodreads div[class^="gr_custom_title"] a:focus,
		.widget_goodreads div[class^="gr_custom_title"] a:hover,
		.widget_goodreads div[class^=gr_custom_container] a:focus,
		.widget_goodreads div[class^=gr_custom_container] a:hover {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.site .widget_wpcom_social_media_icons_widget a:hover,
		.site .widget_wpcom_social_media_icons_widget a:focus {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.button {
			background: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.button.minimal {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.button.minimal:focus,
		.button.minimal:hover {
			background: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		/* Featured Content, Panel Page Template & Widget Footer Top Area */
		.featured-content .hentry.has-post-thumbnail .button,
		.page-template-panel-page .hentry.has-post-thumbnail .button,
		.has-post-thumbnail button, .has-post-thumbnail input[type="button"], .has-post-thumbnail input[type="reset"], .has-post-thumbnail input[type="submit"] {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.widget-footer-top-area .button {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}

		.widget-footer-top-area .button {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.featured-content .hentry.has-post-thumbnail .button:focus,
		.featured-content .hentry.has-post-thumbnail .button:hover,
		.page-template-panel-page .hentry.has-post-thumbnail .button:focus,
		.page-template-panel-page .hentry.has-post-thumbnail .button:hover,
		.has-post-thumbnail button:focus, .has-post-thumbnail input[type="button"]:focus, .has-post-thumbnail input[type="reset"]:focus, .has-post-thumbnail input[type="submit"]:focus,
.has-post-thumbnail button:hover, .has-post-thumbnail input[type="button"]:hover, .has-post-thumbnail input[type="reset"]:hover, .has-post-thumbnail input[type="submit"]:hover {
			color: #2c313f;
		}
		
		.featured-content .hentry.has-post-thumbnail .button.minimal:focus,
		.featured-content .hentry.has-post-thumbnail .button.minimal:hover,
		.page-template-panel-page .hentry.has-post-thumbnail .button.minimal:focus,
		.page-template-panel-page .hentry.has-post-thumbnail .button.minimal:hover {
			color: #2c313f;
		}
		
		.widget-footer-top-area .button.minimal:focus,
		.widget-footer-top-area .button.minimal:hover {
			background: #fff;
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.main-navigation .button.minimal a:focus {
			background: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.main-navigation .button.minimal a {
			color: <?php echo esc_attr( $primary_color ); ?>;
		}
		
		.entry-hero:before,
		.site-content-wrapper .has-post-thumbnail .entry-header:before,
		.featured-content .hentry.has-post-thumbnail:before,
		.page-template-panel-page .hentry.has-post-thumbnail:before {
			background-color: <?php echo esc_attr( $primary_color ); ?>;
			background-image: inherit;
		}
	</style>
	<?php endif; ?>
	
	<?php
}